@@ -1160,7 +1160,7 @@ None by default.
   void BeginShaderMode(Shader shader)
   void BeginTextureMode(RenderTexture2D target)
   void BeginVrDrawing(void)
-  bool ChangeDirectory(const char *dir)
+  bool ChangeDirectory(char *dir)
   bool CheckCollisionBoxSphere(BoundingBox box, Vector3 centerSphere, float radiusSphere)
   bool CheckCollisionBoxes(BoundingBox box1, BoundingBox box2)
   bool CheckCollisionCircleRec(Vector2 center, float radius, Rectangle rec)
@@ -1228,8 +1228,8 @@ None by default.
   void DrawSphere(Vector3 centerPos, float radius, Color color)
   void DrawSphereEx(Vector3 centerPos, float radius, int rings, int slices, Color color)
   void DrawSphereWires(Vector3 centerPos, float radius, int rings, int slices, Color color)
-  void DrawText(const char *text, int posX, int posY, int fontSize, Color color)
-  void DrawTextEx(Font font, const char* text, Vector2 position, float fontSize, float spacing, Color tint)
+  void DrawText(char *text, int posX, int posY, int fontSize, Color color)
+  void DrawTextEx(Font font, char* text, Vector2 position, float fontSize, float spacing, Color tint)
   void DrawTexture(Texture2D texture, int posX, int posY, Color tint)
   void DrawTextureEx(Texture2D texture, Vector2 position, float rotation, float scale, Color tint)
   void DrawTexturePro(Texture2D texture, Rectangle sourceRec, Rectangle destRec, Vector2 origin, float rotation, Color tint)
@@ -1245,10 +1245,10 @@ None by default.
   void EndShaderMode(void)
   void EndTextureMode(void)
   void EndVrDrawing(void)
-  void ExportImage(const char *fileName, Image image)
-  void ExportMesh(const char *fileName, Mesh mesh)
+  void ExportImage(char *fileName, Image image)
+  void ExportMesh(char *fileName, Mesh mesh)
   Color Fade(Color color, float alpha)
-  const char *FormatText(const char *text, ...)
+  char *FormatText(char *text, ...)
   Image GenImageCellular(int width, int height, int tileSize)
   Image GenImageChecked(int width, int height, int checksX, int checksY, Color col1, Color col2)
   Image GenImageColor(int width, int height, Color color)
@@ -1279,15 +1279,15 @@ None by default.
   Rectangle GetCollisionRec(Rectangle rec1, Rectangle rec2)
   Color GetColor(int hexValue)
   Font GetDefaultFont(void)
-  const char *GetDirectoryPath(const char *fileName)
-  const char *GetExtension(const char *fileName)
+  char *GetDirectoryPath(char *fileName)
+  char *GetExtension(char *fileName)
   int GetFPS(void)
-  const char *GetFileName(const char *filePath)
+  char *GetFileName(char *filePath)
   float GetFrameTime(void)
   int GetGamepadAxisCount(int gamepad)
   float GetGamepadAxisMovement(int gamepad, int axis)
   int GetGamepadButtonPressed(void)
-  const char *GetGamepadName(int gamepad)
+  char *GetGamepadName(int gamepad)
   int GetGestureDetected(void)
   float GetGestureDragAngle(void)
   Vector2 GetGestureDragVector(void)
@@ -1311,7 +1311,7 @@ None by default.
   int GetScreenHeight(void)
   int GetScreenWidth(void)
   Shader GetShaderDefault(void)
-  int GetShaderLocation(Shader shader, const char *uniformName)
+  int GetShaderLocation(Shader shader, char *uniformName)
   Image GetTextureData(Texture2D texture)
   Texture2D GetTextureDefault(void)
   double GetTime(void)
@@ -1321,7 +1321,7 @@ None by default.
   int GetTouchY(void)
   VrDeviceInfo GetVrDeviceInfo(int vrDeviceType)
   float *GetWaveData(Wave wave)
-  const char *GetWorkingDirectory(void)
+  char *GetWorkingDirectory(void)
   Vector2 GetWorldToScreen(Vector3 position, Camera3D camera)
   void HideCursor(void)
   void ImageAlphaClear(Image *image, Color color, float threshold)
@@ -1339,8 +1339,8 @@ None by default.
   void ImageDither(Image *image, int rBpp, int gBpp, int bBpp, int aBpp)
   void ImageDraw(Image *dst, Image src, Rectangle srcRec, Rectangle dstRec)
   void ImageDrawRectangle(Image *dst, Vector2 position, Rectangle rec, Color color)
-  void ImageDrawText(Image *dst, Vector2 position, const char *text, int fontSize, Color color)
-  void ImageDrawTextEx(Image *dst, Vector2 position, Font font, const char *text, float fontSize, float spacing, Color color)
+  void ImageDrawText(Image *dst, Vector2 position, char *text, int fontSize, Color color)
+  void ImageDrawTextEx(Image *dst, Vector2 position, Font font, char *text, float fontSize, float spacing, Color color)
   void ImageFlipHorizontal(Image *image)
   void ImageFlipVertical(Image *image)
   void ImageFormat(Image *image, int newFormat)
@@ -1350,25 +1350,25 @@ None by default.
   void ImageResizeNN(Image *image, int newWidth,int newHeight)
   void ImageRotateCCW(Image *image)
   void ImageRotateCW(Image *image)
-  Image ImageText(const char *text, int fontSize, Color color)
-  Image ImageTextEx(Font font, const char *text, float fontSize, float spacing, Color tint)
+  Image ImageText(char *text, int fontSize, Color color)
+  Image ImageTextEx(Font font, char *text, float fontSize, float spacing, Color tint)
   void ImageToPOT(Image *image, Color fillColor)
   void InitAudioDevice(void)
   AudioStream InitAudioStream(unsigned int sampleRate, unsigned int sampleSize, unsigned int channels)
   void InitVrSimulator(VrDeviceInfo info)
-  void InitWindow(int width, int height, const char *title)
+  void InitWindow(int width, int height, char *title)
   bool IsAudioBufferProcessed(AudioStream stream)
   bool IsAudioDeviceReady(void)
   bool IsAudioStreamPlaying(AudioStream stream)
   bool IsCursorHidden(void)
   bool IsFileDropped(void)
-  bool IsFileExtension(const char *fileName, const char *ext)
+  bool IsFileExtension(char *fileName, char *ext)
   bool IsGamepadAvailable(int gamepad)
   bool IsGamepadButtonDown(int gamepad, int button)
   bool IsGamepadButtonPressed(int gamepad, int button)
   bool IsGamepadButtonReleased(int gamepad, int button)
   bool IsGamepadButtonUp(int gamepad, int button)
-  bool IsGamepadName(int gamepad, const char *name)
+  bool IsGamepadName(int gamepad, char *name)
   bool IsGestureDetected(int gesture)
   bool IsKeyDown(int key)
   bool IsKeyPressed(int key)
@@ -1383,35 +1383,35 @@ None by default.
   bool IsVrSimulatorReady(void)
   bool IsWindowMinimized(void)
   bool IsWindowReady(void)
-  Font LoadFont(const char *fileName)
-  CharInfo *LoadFontData(const char *fileName, int fontSize, int *fontChars, int charsCount, bool sdf)
-  Font LoadFontEx(const char *fileName, int fontSize, int charsCount, int *fontChars)
-  Image LoadImage(const char *fileName)
+  Font LoadFont(char *fileName)
+  CharInfo *LoadFontData(char *fileName, int fontSize, int *fontChars, int charsCount, bool sdf)
+  Font LoadFontEx(char *fileName, int fontSize, int charsCount, int *fontChars)
+  Image LoadImage(char *fileName)
   Image LoadImageEx(Color *pixels, int width, int height)
   Image LoadImagePro(void *data, int width, int height, int format)
-  Image LoadImageRaw(const char *fileName, int width, int height, int format, int headerSize)
+  Image LoadImageRaw(char *fileName, int width, int height, int format, int headerSize)
   Image LoadImageFromAV(SV *array_ref, SV *color_cb)
   Image LoadImageFromAV_uninitialized_mem(SV *array_ref, SV *color_cb)
   Image LoadImageFromAV_transposed(SV *array_ref, SV *color_cb)
   Image LoadImageFromAV_transposed_uninitialized_mem(SV *array_ref, SV *color_cb)
-  Material LoadMaterial(const char *fileName)
+  Material LoadMaterial(char *fileName)
   Material LoadMaterialDefault(void)
-  Mesh LoadMesh(const char *fileName)
-  Model LoadModel(const char *fileName)
+  Mesh LoadMesh(char *fileName)
+  Model LoadModel(char *fileName)
   Model LoadModelFromMesh(Mesh mesh)
-  Music LoadMusicStream(const char *fileName)
+  Music LoadMusicStream(char *fileName)
   RenderTexture2D LoadRenderTexture(int width, int height)
-  Shader LoadShader(const char *vsFileName, const char *fsFileName)
+  Shader LoadShader(char *vsFileName, char *fsFileName)
   Shader LoadShaderCode(char *vsCode, char *fsCode)
-  Sound LoadSound(const char *fileName)
+  Sound LoadSound(char *fileName)
   Sound LoadSoundFromWave(Wave wave)
-  char *LoadText(const char *fileName)
-  Texture2D LoadTexture(const char *fileName)
+  char *LoadText(char *fileName)
+  Texture2D LoadTexture(char *fileName)
   Texture2D LoadTextureFromImage(Image image)
-  Wave LoadWave(const char *fileName)
+  Wave LoadWave(char *fileName)
   Wave LoadWaveEx(void *data, int sampleCount, int sampleRate, int sampleSize, int channels)
-  int MeasureText(const char *text, int fontSize)
-  Vector2 MeasureTextEx(Font font, const char *text, float fontSize, float spacing)
+  int MeasureText(char *text, int fontSize)
+  Vector2 MeasureTextEx(Font font, char *text, float fontSize, float spacing)
   void MeshBinormals(Mesh *mesh)
   BoundingBox MeshBoundingBox(Mesh mesh)
   void MeshTangents(Mesh *mesh)
@@ -1457,7 +1457,7 @@ None by default.
   void SetWindowMonitor(int monitor)
   void SetWindowPosition(int x, int y)
   void SetWindowSize(int width, int height)
-  void SetWindowTitle(const char *title)
+  void SetWindowTitle(char *title)
   void ShowCursor(void)
   void ShowLogo(void)
   void StopAudioStream(AudioStream stream)
@@ -1465,11 +1465,11 @@ None by default.
   void StopSound(Sound sound)
   int StorageLoadValue(int position)
   void StorageSaveValue(int position, int value)
-  const char *SubText(const char *text, int position, int length)
-  void TakeScreenshot(const char *fileName)
+  char *SubText(char *text, int position, int length)
+  void TakeScreenshot(char *fileName)
   void ToggleFullscreen(void)
   void ToggleVrMode(void)
-  void TraceLog(int logType, const char *text, ...)
+  void TraceLog(int logType, char *text, ...)
   void UnloadFont(Font font)
   void UnloadImage(Image image)
   void UnloadMaterial(Material material)
